@@ -38,21 +38,22 @@ typedef struct {
   gint value;
   gboolean direction;
 } card_type;
-typedef card_type* hcard_type;
+typedef card_type *hcard_type;
 
 
 /*
  * Variables
  */
-extern GdkBitmap *mask;
+extern GdkBitmap *card_mask;
 
 /*
  * Functions
  */
-GdkPixmap* get_card_picture (gint, gint);
-GdkPixmap* get_slot_pixmap ( void );
-GdkPixmap* get_background_pixmap ( void );
-GdkPixmap* get_card_back_pixmap ( void );
+GdkPixmap *get_card_picture (gint, gint);
+GdkPixmap *get_droptarget_pixmap (gint, gint, gboolean);
+GdkPixmap *get_slot_pixmap (void);
+GdkPixmap *get_background_pixmap (void);
+GdkPixmap *get_card_back_pixmap (void);
 
 void set_card_size (gint width, gint height);
 void set_card_theme (gchar * theme);
@@ -60,5 +61,4 @@ void set_card_theme (gchar * theme);
 void load_pixmaps (void);
 void free_pixmaps (void);
 
-void add_card (GList**, hcard_type);
 #endif
