@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import os, os.path
+import errno
 import gettext
 
 APP_DATA_DIR    = os.path.join('/usr/local', 'share') 
@@ -22,7 +23,7 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.18.1.1"
+VERSION = "2.18.2"
 APPNAME = _("glChess")
 
 COPYRIGHT     = _('Copyright 2005-2007 Robert Ancell (and contributors)')
@@ -59,4 +60,8 @@ _("You should have received a copy of the GNU General Public License "
 #2D Models:
 #Copyright World Wide Web Consortium, (Massachusetts Institute of Technology, Institut National de Recherche en Informatique et en Automatique, Keio University). All Rights Reserved. http://www.w3.org/Consortium/Legal/"""
 
-if not os.path.exists(DATA_DIR): os.makedirs(DATA_DIR)
+try:
+    os.makedirs(DATA_DIR)
+except OSError, e:
+    if e.errno != errno.EEXIST:
+       print 'Unable to make data directory %(dir)s: %(error)s' % {'dir': DATA_DIR, 'error': e.strerror}
