@@ -578,6 +578,12 @@ class GtkUI(glchess.ui.UI):
     __defaultBlackAI   = None
 
     __attentionCounter = 0
+    
+    # The window width and height when unmaximised and not fullscreen
+    width              = None
+    height             = None
+    isFullscreen       = False
+    isMaximised        = False
 
     def __init__(self):
         """Constructor for a GTK+ glChess GUI"""
