@@ -461,11 +461,13 @@ class View(ui.ViewFeedback):
     
     def select(self, x, y):
         """Called by ui.ViewFeedback"""
-        self.activeScene.select(x, y)
+        if self.activeScene is not None:
+            self.activeScene.select(x, y)
     
     def deselect(self, x, y):
         """Called by ui.ViewFeedback"""
-        self.activeScene.deselect(x, y)
+        if self.activeScene is not None:
+            self.activeScene.deselect(x, y)
     
     def setMoveNumber(self, moveNumber):
         """Called by ui.ViewFeedback"""
@@ -687,8 +689,7 @@ class UI(gtkui.GtkUI):
         except KeyError:
             return False
         else:
-            player.read()
-            return True
+            return player.read()
 
     def onGameStart(self, gameName, allowSpectators, duration, white, black):
         """Called by UI"""
@@ -1001,20 +1002,24 @@ class Application:
         fname = self.__config.getAutosavePath()
         print 'Auto-saving to ' + fname + '...'
         
-        f = file(fname, 'a')
-        for g in self.__games:
-            # Ignore games that are saved to a file
-            if g.fileName is not None:
-                continue
+        try:
+            f = file(fname, 'a')
+            for g in self.__games:
+                # Ignore games that are saved to a file
+                if g.fileName is not None:
+                    continue
             
-            pgnGame = chess.pgn.PGNGame()
-            g.toPGN(pgnGame)
+                pgnGame = chess.pgn.PGNGame()
+                g.toPGN(pgnGame)
             
-            lines = pgnGame.getLines()
-            for line in lines:
-                f.write(line + '\n')
-            f.write('\n')
-        f.close()
+                lines = pgnGame.getLines()
+                for line in lines:
+                    f.write(line + '\n')
+                f.write('\n')
+            f.close()
+        except IOError, e:
+            # FIXME: This should be in a dialog
+            print 'Unable to autosave to %s: %s' % (fname, str(e))
 
 if __name__ == '__main__':
     app = Application()
