@@ -160,13 +160,15 @@ network_gui_update (void)
 #endif
 }
 
-static void
+static gboolean
 window_state_cb (GtkWidget * widget, GdkEventWindowState * event)
 {
   /* Handle fullscreen, in case something else takes us to/from fullscreen. */
   if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
     set_fullscreen_actions (event->new_window_state
 			    & GDK_WINDOW_STATE_FULLSCREEN);
+    
+  return FALSE;
 }
 
 
@@ -232,7 +234,7 @@ quit_cb (GObject * object, gpointer data)
 static void
 about_cb (GtkAction * action, gpointer data)
 {
-  const gchar *authors[] = { "Sean MacIsaac", "Ian Peters", NULL };
+  const gchar *authors[] = { "Sean MacIsaac", "Ian Peters", "Andreas Røsdal", NULL };
 
   const gchar *documenters[] = { "Kevin Breit", NULL };
   gchar *license = games_get_license (_("Nibbles"));
@@ -241,7 +243,7 @@ about_cb (GtkAction * action, gpointer data)
 			 "name", _("Nibbles"),
 			 "version", VERSION,
 			 "copyright",
-			 "Copyright \xc2\xa9 1999-2006 Sean MacIsaac, Ian Peters",
+			 "Copyright \xc2\xa9 1999-2007 Sean MacIsaac, Ian Peters, Andreas Røsdal",
 			 "license", license, "comments",
 			 _("A worm game for GNOME."), "authors", authors,
 			 "documenters", documenters, "translator-credits",
@@ -307,7 +309,7 @@ draw_board ()
 
 }
 
-static gint
+static gboolean
 window_configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
 {
   gnibbles_properties_set_height (event->height);
@@ -315,7 +317,7 @@ window_configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
   return FALSE;
 }
 
-static gint
+static gboolean
 configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
 {
   int tilesize, ts_x, ts_y;
@@ -388,7 +390,7 @@ new_game_2_cb (GtkWidget * widget, gpointer data)
 				      G_CALLBACK (key_press_cb), NULL);
 #ifdef GGZ_CLIENT
     if (!main_id && ggz_network_mode && network_is_host ()) {
-      main_id = g_timeout_add (GAMEDELAY * properties->gamespeed,
+      main_id = g_timeout_add (GAMEDELAY * (properties->gamespeed + NETDELAY),
 			       (GSourceFunc) network_loop, NULL);
     } else
 #endif
@@ -659,7 +661,10 @@ main_loop (gpointer data)
       g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
       keyboard_id = 0;
     }
-    main_id = 0;
+    if (main_id) {
+      g_source_remove (main_id);
+      main_id = 0;
+    }
     if (add_bonus_id) {
       g_source_remove (add_bonus_id);
     }
@@ -708,8 +713,11 @@ main_loop (gpointer data)
     if (add_bonus_id) {
       g_source_remove (add_bonus_id);
     }
+    if (main_id) {
+      g_source_remove (main_id);
+      main_id = 0;
+    }
     add_bonus_id = 0;
-    main_id = 0;
     erase_id = g_timeout_add (ERASETIME / ERASESIZE,
 			      (GSourceFunc) erase_worms_cb,
 			      (gpointer) ERASESIZE);
@@ -729,7 +737,10 @@ main_loop (gpointer data)
       g_source_remove (add_bonus_id);
     }
     add_bonus_id = 0;
-    main_id = 0;
+    if (main_id) {
+      g_source_remove (main_id);
+      main_id = 0;
+    }
     if ((current_level < MAXLEVEL) && (!properties->random
 				       || ggz_network_mode))
       current_level++;
