@@ -260,7 +260,8 @@ class NumberBox (gtk.Widget):
     def show_note_editor (self, top=True):
         alloc = self.get_allocation()
         w = gtk.Window()
-        w.set_type_hint(gtk.WINDOW_POPUP)
+        w.set_property('skip-pager-hint', True)
+        w.set_property('skip-taskbar-hint', True)
         w.set_decorated(False)
         w.set_position(gtk.WIN_POS_MOUSE)
         w.set_size_request(alloc.width,alloc.height/2)
@@ -289,7 +290,8 @@ class NumberBox (gtk.Widget):
         #return
         w = gtk.Window()
         w.set_app_paintable(True)
-        w.set_type_hint(gtk.WINDOW_POPUP)
+        w.set_property('skip-pager-hint', True)
+        w.set_property('skip-taskbar-hint', True)
         w.set_decorated(False)
         ns = NumberSelector(upper=self.upper,default=self.get_value())
         def number_changed_cb (b):
@@ -304,7 +306,6 @@ class NumberBox (gtk.Widget):
         r = w.get_allocation()
         my_origin = self.window.get_origin()
         x,y = self.window.get_size()
-        w.show()
         popupx,popupy = w.get_size()
         overlapx = popupx-x
         overlapy = popupy-y
@@ -313,6 +314,7 @@ class NumberBox (gtk.Widget):
         #print 'popup size is',popupx,popupy
         #print 'overlaps are ',overlapx,overlapy
         w.move(my_origin[0]-(overlapx/2),my_origin[1]-(overlapy/2))
+        w.show()
         self.npicker = w
 
     def set_text_interactive (self,text):
@@ -1176,7 +1178,8 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         if not e: return
 	filled = self.grid.auto_fill_for_xy(e.x,e.y)
         if filled and filled!=-1:
-            self.add_value(filled[0][0],filled[0][1],filled[1])
+            e.set_text_interactive('')
+            e.set_text_interactive(str(filled[1]))
     
     @simple_debug
     def mark_impossible_implications (self, x, y):
