@@ -38,8 +38,8 @@ typedef struct _GamesCardPixmapsClass {
 } GamesCardPixmapsClass;
 
 #define GAMES_TYPE_CARD_PIXMAPS (games_card_pixmaps_get_type ())
-#define GAMES_CARD_PIXMAPS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_CARD_PIXMAPS, GamesCardImages))
-#define GAMES_CARD_PIXMAPS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_CARD_PIXMAPS, GamesCardImagesClass))
+#define GAMES_CARD_PIXMAPS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_CARD_PIXMAPS, GamesCardPixmaps))
+#define GAMES_CARD_PIXMAPS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_CARD_PIXMAPS, GamesCardPixmapsClass))
 #define GAMES_IS_CARD_PIXMAPS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_CARD_PIXMAPS))
 #define GAMES_IS_CARD_PIXMAPS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_CARD_PIXMAPS))
 #define GAMES_CARD_PIXMAPS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_CARD_PIXMAPS))
